getData: Get the Geometry Data for a File.

View source: R/modelDerivative.R

getDataR Documentation

Get the Geometry Data for a File.

Description

Get the geometry of an uploaded file using the Model Derivative API.

Usage

getData(guid = NULL, urn = NULL, token = NULL)

Arguments

guid

A string. GUID retrieved via the getMetadata function.

urn

A string. Source URN (objectId) for the file. Note the URN must be Base64 encoded. To encode the URN, see, for example, the jsonlite::base64_enc function.

token

A string or aps_token object with data:read and data:write scopes.

Value

An object containing the geometry data for the selected file.

Examples

## Not run: 
# Get the geometry data for the "aerial.dwg" svf file
resp <- getData(guid = myGuid, urn = myEncodedUrn, token = myToken)

## End(Not run)

AutoDeskR documentation built on May 28, 2026, 5:08 p.m.