translateSvf2: Translate a File into SVF2 Format.

View source: R/modelDerivative.R

translateSvf2R Documentation

Translate a File into SVF2 Format.

Description

Translate an uploaded file into SVF2 format using the Model Derivative API. SVF2 is the next-generation viewer format: approximately 30 SVF and faster to load in the Autodesk Viewer. Use it in place of translateSvf for new projects.

Usage

translateSvf2(urn = NULL, token = NULL, views = c("2d", "3d"))

Arguments

urn

A string. Source URN (objectId) for the file. Note the URN must be Base64 encoded. To encode the URN, see, for example, the jsonlite::base64_enc function.

token

A string or aps_token object with data:read and data:write scopes.

views

A character vector. Views to generate. Defaults to c("2d", "3d").

Value

An object containing the result, urn, and additional activity information.

Examples

## Not run: 
# Translate the "aerial.dwg" file into SVF2 format
myEncodedUrn <- jsonlite::base64_enc(myUrn)
resp <- translateSvf2(urn = myEncodedUrn, token = myToken)

## End(Not run)

AutoDeskR documentation built on May 28, 2026, 5:08 p.m.