Upload a design file of any size to an app-managed bucket using the signed
S3 URL approach recommended by AutoDesk Platform Services (APS). Unlike
uploadFile, this function supports files larger than 100 MB.
Upload a design file of any size to an app-managed bucket using the signed
S3 URL approach recommended by AutoDesk Platform Services (APS). Unlike
uploadFile, this function supports files larger than 100 MB.