uploadFileSigned: Upload a File Using Signed S3 URLs.

View source: R/dataManagement.R

uploadFileSignedR Documentation

Upload a File Using Signed S3 URLs.

Description

Upload a design file of any size to an app-managed bucket using the signed S3 URL approach recommended by AutoDesk Platform Services (APS). Unlike uploadFile, this function supports files larger than 100 MB.

Usage

uploadFileSigned(file = NULL, token = NULL, bucket = "mybucket")

Arguments

file

A string. File path.

token

A string or aps_token object with data:write scope.

bucket

A string. Unique bucket name. Defaults to mybucket.

Value

An object containing the finalized upload response with bucketKey, objectId, objectKey, size, and location.

Examples

## Not run: 
# Upload a large file using signed S3 URLs
resp <- uploadFileSigned(
  file   = "path/to/large_model.rvt",
  token  = myToken,
  bucket = "mybucket"
)
myUrn <- resp$content$objectId

## End(Not run)

AutoDeskR documentation built on May 28, 2026, 5:08 p.m.